@@ -2,3 +2,5 @@
 from .programs import Programs
 from .program import Program
 from .program_scope import ProgramScope
+from .domain import Domain
+from .domains import Domains
