@@ -7,7 +7,7 @@ from typing import List, Optional
 from pathlib import Path, PurePath
 from datetime import datetime, timedelta
 
-from bbrecon import BugBountyRecon, Program, ApiResponseError
+from bbrecon import BugBountyRecon, Program, ApiResponseError, Domain
 
 from .utils import config, update
 
@@ -134,6 +134,22 @@ def output_wide_scopes_table(scopes: List[dict]):
     typer.echo(tabulate(data, headers, tablefmt="plain"))
 
 
+def output_json_domains_table(domains: List[Domain]):
+    typer.echo(json.dumps([domain.to_dict() for domain in domains], indent=4))
+
+
+def output_narrow_domains_table(domains: List[Domain]):
+    headers = ["SLUG", "DOMAIN", "CREATED"]
+    data = []
+    for domain in domains:
+        created_at = domain.created_at.strftime("%Y-%m-%d")
+        data.append([domain.program, domain.name, created_at])
+    typer.echo(tabulate(data, headers, tablefmt="plain"))
+
+
+output_wide_domains_table = output_narrow_domains_table
+
+
 @get.command("programs")
 def programs_get(
     program_slugs: Optional[List[str]] = typer.Argument(None),
@@ -261,6 +277,54 @@ def scopes_get(
     globals()[f"output_{output}_scopes_table"](scopes)
 
 
+@get.command("domains")
+def domains_get(
+    program_slugs: List[str] = typer.Argument(None),
+    output: OutputFormat = typer.Option(
+        OutputFormat.wide, "--output", "-o", help="Output format."
+    ),
+    created_since: str = typer.Option(
+        None,
+        "--since",
+        "-s",
+        help="""
+Filter for domains created after a certain date. A specific date in the
+format '%Y-%m-%d' can be supplied. Alternatively, the following keywords are supported:
+'yesterday', 'last-week', 'last-month', 'last-year' as well as 'last-X-days'
+(where 'X' is an integer).
+    """,
+    ),
+):
+    """
+    Display many domains, in a table or as JSON.
+
+    If a list of slugs is provided as CLI arguments, the command will fetch domains for
+    the specified programs.
+    """
+
+    if not created_since and not program_slugs:
+        typer.echo(
+            "You can't query all domains like this. "
+            "Specify program slugs or use `--since`."
+        )
+        exit(1)
+
+    if created_since:
+        try:
+            created_since = get_datetime_from_input(created_since)
+        except InvalidDateInputError:
+            typer.echo(f"Invalid date input '{created_since}', see '--help'.")
+            exit(1)
+
+    try:
+        domains = list(bb.domains(programs=program_slugs, created_since=created_since))
+    except ApiResponseError as e:
+        typer.echo(e)
+        exit()
+
+    globals()[f"output_{output}_domains_table"](domains)
+
+
 @configure.command("key")
 def key_configure():
     path = PurePath.joinpath(Path.home(), ".bbrecon")
